#

##

##

##

##

    	smart contracts

    	tags
    		# treaties

    	summary

    	objectives ranked

    		[ ] These need to be voidable and eraseable at any
    			time by a vote.

    			[ ] could have an elected group
    				responsibile for moderating these.

    				[ ] name possibilities:

    						community safety group

    						immunology group

    				[ ] if nullified then

    					( ) return to sender

    				[ ] the nullification option could be selected
    					by the publisher of the contract.

    	possibilities

    		[ ] { demuxers, splitters }

    		[ ] circuitry components

    		[ ] { subscriptions, routine payments }

    				If you sign the contract, money is sent from your
    				account to a designated address on certain

    					( ) block numbers,
    					( ) balance sheet numbers

    				until you or the consensus void the contract.

    		[ ] loans

    		[ ] options based on on chain derivatives